#[repr(transparent)]pub struct SidebarItem {
inner: TypedObjectRef<SidebarItem, ()>,
phantom: PhantomData<()>,
}Expand description
A top-level item in the sidebar.
This wraps the inner item to handle its visibility and whether it should show its children (i.e. whether it is “expanded”).
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<SidebarItem, ()>phantom: PhantomData<()>Implementations
Sourceimpl SidebarItem
impl SidebarItem
Sourcepub fn inner_item(
&self,
) -> <BoundConstructOnlyObject<Object> as Property>::Value
pub fn inner_item( &self, ) -> <BoundConstructOnlyObject<Object> as Property>::Value
The item wrapped by this SidebarItem.
Sourcepub fn inhibit_expanded(&self) -> <Cell<bool> as Property>::Value
pub fn inhibit_expanded(&self) -> <Cell<bool> as Property>::Value
Whether to inhibit the expanded state.
It means that all the sections will be expanded regardless of their “is-expanded” property.
Sourcepub fn set_inhibit_expanded<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_inhibit_expanded<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether to inhibit the expanded state.
It means that all the sections will be expanded regardless of their “is-expanded” property.
Sourcepub fn connect_inner_item_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_inner_item_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the inner-item property
Sourcepub fn connect_is_visible_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_visible_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-visible property
Sourcepub fn connect_inhibit_expanded_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_inhibit_expanded_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the inhibit-expanded property
Sourcepub fn notify_inner_item(&self)
pub fn notify_inner_item(&self)
Notify listeners of a change in the inner-item property
Sourcepub fn notify_is_visible(&self)
pub fn notify_is_visible(&self)
Notify listeners of a change in the is-visible property
Sourcepub fn notify_inhibit_expanded(&self)
pub fn notify_inhibit_expanded(&self)
Notify listeners of a change in the inhibit-expanded property
Sourceimpl SidebarItem
impl SidebarItem
Sourcepub(crate) fn update_visibility_for_room_category(
&self,
source_category: Option<RoomCategory>,
)
pub(crate) fn update_visibility_for_room_category( &self, source_category: Option<RoomCategory>, )
Update the visibility of this item for the drag-n-drop of a room with the given category.